Upload file into rucio — Rucio 0.3.8 documentation

# Upload file into rucio

Replica can be in one the following statuses:

- `queued`

  The replica identifier has been reserved and no data has been uploaded.

- `active`

  Denotes a replica that is fully available.

digraph foo { rankdir=LR; size="4" node [shape = circle]; queued; node [shape = point ]; qi; node [shape = circle]; active; node [shape = point ]; qf; qi -> queued; queued -> active [ label = "commitRegistration" ]; active -> qf; }